@@ -8,20 +8,28 @@ import python_utils
 
 
 @pytest.mark.parametrize(
-    'timeout,interval,interval_multiplier,maximum_interval,iterable,result', [
+    'timeout,interval,interval_multiplier,maximum_interval,iterable,result',
+    [
         (0.2, 0.1, 0.4, 0.2, python_utils.acount, 2),
         (0.3, 0.1, 0.4, 0.2, python_utils.acount(), 3),
         (0.3, 0.06, 1.0, None, python_utils.acount, 5),
-        (timedelta(seconds=0.1), timedelta(seconds=0.06),
-         2.0, timedelta(seconds=0.1), python_utils.acount, 2),
-    ])
+        (
+            timedelta(seconds=0.1),
+            timedelta(seconds=0.06),
+            2.0,
+            timedelta(seconds=0.1),
+            python_utils.acount,
+            2,
+        ),
+    ],
+)
 @pytest.mark.asyncio
-async def test_aio_timeout_generator(timeout, interval, interval_multiplier,
-                                     maximum_interval, iterable, result):
+async def test_aio_timeout_generator(
+    timeout, interval, interval_multiplier, maximum_interval, iterable, result
+):
     i = None
     async for i in python_utils.aio_timeout_generator(
-        timeout, interval, iterable,
-        maximum_interval=maximum_interval
+        timeout, interval, iterable, maximum_interval=maximum_interval
     ):
         pass
 
@@ -29,18 +37,25 @@ async def test_aio_timeout_generator(timeout, interval, interval_multiplier,
 
 
 @pytest.mark.parametrize(
-    'timeout,interval,interval_multiplier,maximum_interval,iterable,result', [
+    'timeout,interval,interval_multiplier,maximum_interval,iterable,result',
+    [
         (0.01, 0.006, 0.5, 0.01, 'abc', 'c'),
         (0.01, 0.006, 0.5, 0.01, itertools.count, 2),
         (0.01, 0.006, 0.5, 0.01, itertools.count(), 2),
         (0.01, 0.006, 1.0, None, 'abc', 'c'),
-        (timedelta(seconds=0.01),
-         timedelta(seconds=0.006),
-         2.0, timedelta(seconds=0.01),
-         itertools.count, 2),
-    ])
-def test_timeout_generator(timeout, interval, interval_multiplier,
-                           maximum_interval, iterable, result):
+        (
+            timedelta(seconds=0.01),
+            timedelta(seconds=0.006),
+            2.0,
+            timedelta(seconds=0.01),
+            itertools.count,
+            2,
+        ),
+    ],
+)
+def test_timeout_generator(
+    timeout, interval, interval_multiplier, maximum_interval, iterable, result
+):
     i = None
     for i in python_utils.timeout_generator(
         timeout=timeout,
@@ -104,8 +119,7 @@ async def test_aio_generator_timeout_detector_decorator():
 
     # Test regular timeout with clean exit
     @python_utils.aio_generator_timeout_detector_decorator(
-        timeout=0.05,
-        on_timeout=None
+        timeout=0.05, on_timeout=None
     )
     async def generator():
         for i in range(10):
@@ -130,8 +144,7 @@ async def test_aio_generator_timeout_detector_decorator():
 
     # Test total timeout with clean exit
     @python_utils.aio_generator_timeout_detector_decorator(
-        total_timeout=0.1,
-        on_timeout=None
+        total_timeout=0.1, on_timeout=None
     )
     async def generator():
         for i in range(10):
